from .chunk_doc_utils import ChunkDocUtils

class DocUtils(ChunkDocUtils):
    """Class for all document utilities. 
    Primarily should be used as a mixin for future functions
    but can be a standalone.
    # TODO: Extend to Chunk Doc Reading and Chunk Doc Writing
    """
